@@ -53,6 +53,7 @@
 #include "type_308.h"
 #include "type_309.h"
 #include "tapeDB.h"
+#include "hops_complex.h"
 
 #define flip_short(a)   (flip ? r_short_reverse(a)  : a)
 #define flip_unsig(a)   (flip ? r_unsig_reverse(a)  : a)
@@ -495,7 +496,7 @@ int main (int argc, char *argv[])
         else if (strncmp (t1->recId, "230", 3) == 0)
             {
             /* Special case variable-length record */
-            nbuff = sizeof (struct type_230) + (flip_short(t230->nspec_pts) - 1) * sizeof (complex) - k;
+            nbuff = sizeof (struct type_230) + (flip_short(t230->nspec_pts) - 1) * sizeof (hops_complex) - k;
             countt[25]++;       /* Increment record count */
             }
         /* ** Type-300 record? ** */
@@ -1626,6 +1627,7 @@ int main (int argc, char *argv[])
             }           /* End of if type 308 */
         // Type-309 record?
         if (strncmp (t1->recId, "309", 3) == 0)
+            {
             if (strncmp (t309->version_no, "00", 2) == 0)
                 {                   // Mk5B phase cal - version 00
                 printf ("su %d   ntones %d   ",
@@ -1727,6 +1729,7 @@ int main (int argc, char *argv[])
                     printf ("\n");
                     }
                 }
+            }
         /* * tapeDB record? * */
         if (strncasecmp (t1->recId, "TDB", 3) == 0)
             {           /* tapeDB? */
