@@ -9,6 +9,7 @@
 
 #include <stdio.h>
 #include "control.h"
+#include "ffcontrol.h"
 #include "mk4_sizes.h"
 
 #define FALSE 0
@@ -64,6 +65,14 @@ nullify_cblock (struct c_block *cb_ptr)
     cb_ptr -> mbd_anchor      = NULLINT;
     cb_ptr -> ion_smooth      = NULLINT;  
     cb_ptr -> est_pc_manual   = NULLINT;  
+    cb_ptr -> vbp_correct     = NULLINT;  
+    cb_ptr -> vbp_fit         = NULLINT;  
+
+    for (i=0; i<5; i++)
+        {
+        cb_ptr -> vbp_coeffs[i].ref = NULLFLOAT;
+        cb_ptr -> vbp_coeffs[i].rem = NULLFLOAT;
+        }
 
     for (i=0; i<6; i++)
         cb_ptr -> adhoc_poly[i] = NULLFLOAT;
@@ -86,6 +95,8 @@ nullify_cblock (struct c_block *cb_ptr)
         cb_ptr -> dr_window[i]           = NULLFLOAT;
         cb_ptr -> time_span[i]           = NULLINT;
         cb_ptr -> passband[i]            = NULLFLOAT; 
+        cb_ptr -> avxpzoom[i]            = NULLFLOAT;
+        cb_ptr -> avxplopt[i]            = NULLINT;
         cb_ptr -> ion_window[i]          = NULLFLOAT;
         cb_ptr -> adhoc_file[i][0]       = 0; 
         cb_ptr -> adhoc_file_chans[i][0] = 0; 
@@ -93,6 +104,8 @@ nullify_cblock (struct c_block *cb_ptr)
         cb_ptr -> plot_data_dir[i][0]    = 0;
         cb_ptr -> pc_phase_offset[i].ref = NULLFLOAT;
         cb_ptr -> pc_phase_offset[i].rem = NULLFLOAT;
+        cb_ptr -> vbp_file[i][0]         = 0; 
+        cb_ptr -> mount_type[i]          = NULLINT;
         }
 
     cb_ptr -> gen_cf_record = NULLINT;
@@ -109,7 +122,7 @@ nullify_cblock (struct c_block *cb_ptr)
 
     for (i=0; i<MAXFREQ; i++)
         {
-        cb_ptr -> frequency[i] = NULLINT;
+        cb_ptr -> accept_sbs[i] = NULLINT;
 
         cb_ptr -> pc_phase[i][0].ref = NULLFLOAT;
         cb_ptr -> pc_phase[i][1].ref = NULLFLOAT;
@@ -131,6 +144,8 @@ nullify_cblock (struct c_block *cb_ptr)
         cb_ptr -> delay_offs_pol[i][1].ref = NULLFLOAT;
         cb_ptr -> delay_offs_pol[i][0].rem = NULLFLOAT;
         cb_ptr -> delay_offs_pol[i][1].rem = NULLFLOAT;
+        cb_ptr -> chid[i] = '\0';
+        cb_ptr -> chid_rf[i] = 0.0;
         }
 
     for (i=0; i<2*MAXFREQ; i++)
