@@ -105,5 +105,5 @@ static char fchars[64] =
      'W','X','Y','Z','0','1','2','3','4','5','6','7','8','9','$','%'};
 
 static char *polab[4] =
-        { "LL", "RR", "LR", "RL" };
+        { (char*)"LL", (char*)"RR", (char*)"LR", (char*)"RL" };
 #endif
