@@ -16,11 +16,57 @@
 #include <time.h>
 #include <unistd.h>
 
+#include "msg.h"
+#include "hops_complex.h"
 #define PLOT_DATA_DIR_IMPLEMENTATION 1
 #include "plot_data_dir.h"
 
+
+/* implementation details, not needed by callers */
+#define PDDCOLS 132
+/* double expansion required for some reason */
+#define PDD_DESCRIBE(F,X)   fprintf(F,"#  %-21.20s 0x%08X\n", #X, X)
+#define PDD_DESCRIBe(F,X,C) fprintf(F,"#  %-21.20s 0x%08X  (%s)\n", #X, X, C)
+/* components of HOPS_PLOT_DATA_MASK */
+#define PDD_HEADER          0x00000001
+#define PDD_SBD_AMP         0x00000002
+#define PDD_MBD_AMP         0x00000004
+#define PDD_DLYRATE         0x00000008
+#define PDD_XPSPEC          0x00000010
+#define PDD_PHASOR          0x00000020
+#define PDD_WEIGHTS         0x00000040
+#define PDD_MEAN_AP         0x00000080
+#define PDD_SEG_AMP         0x00000100
+#define PDD_SEG_PHS         0x00000200
+#define PDD_SEG_FRAC_USB    0x00000400
+#define PDD_SEG_FRAC_LSB    0x00000800
+#define PDD_SEG_REFSCNT_USB 0x00001000
+#define PDD_SEG_REFSCNT_LSB 0x00002000
+#define PDD_SEG_REMSCNT_USB 0x00004000
+#define PDD_SEG_REMSCNT_LSB 0x00008000
+#define PDD_SEG_REFBIAS_USB 0x00010000
+#define PDD_SEG_REFBIAS_LSB 0x00020000
+#define PDD_SEG_REMBIAS_USB 0x00040000
+#define PDD_SEG_REMBIAS_LSB 0x00080000
+#define PDD_SEG_REFPCAL     0x00100000
+#define PDD_SEG_REMPCAL     0x00200000
+#define PDD_SEG_PLOT_INFO   0x00400000
+#define PDD_SEG_RESERVED1   0x00800000
+#define PDD_SEG_AMP_FILTER  0x01000000
+#define PDD_MODELINFO       0x02000000
+#define PDD_FINEPRINT       0x04000000
+#define PDD_SEG_RESERVED2   0x08000000
+#define PDD_SEG_RESERVED3   0x10000000
+#define PDD_SEG_RESERVED4   0x20000000
+#define PDD_SEG_RESERVED5   0x40000000
+#define PDD_LEGEND          0x80000000
+#define PDD_ALL             0x83FFFFFF
+#define PDD_SOME \
+    (PDD_HEADER|PDD_SBD_AMP|PDD_MBD_AMP|PDD_DLYRATE|PDD_XPSPEC|PDD_PHASOR \
+    |PDD_WEIGHTS|PDD_MEAN_AP|PDD_SEG_AMP|PDD_SEG_PHS|PDD_LEGEND)
+
+
 #define R2D(RAD) ((RAD) * (M_1_PI * 180.0))
-extern void msg (char *, int, ...);
 extern char control_filename[];
 
 /*
@@ -128,8 +174,8 @@ static void dump_plot_info(FILE *fp, struct type_dump *dp)
             /* line one */
             dp->pass->pass_data[ii].freq_code,
             dp->pass->pass_data[ii].frequency,
-            carg (dp->status->fringe[ii]) * 180.0 / M_PI,
-            cabs (dp->status->fringe[ii]),
+            arg_complex (dp->status->fringe[ii]) * 180.0 / M_PI,
+            abs_complex (dp->status->fringe[ii]),
             dp->status->sbdbox[ii],
             dp->status->ap_num[0][ii], dp->status->ap_num[1][ii],
             /* line two */
@@ -279,7 +325,18 @@ static void dump_fineprint(FILE *fp, struct type_dump *dp)
                 "undefined");
 
     fprintf(fp, "# ControlFile             '%s'\n", control_filename);
-    //FIXME -- yet morethings
+    if (dp->param->passband[0] != 0.0 || dp->param->passband[1] != 1.0E6)
+        fprintf(fp, "# PassbandInAvXPSpectrum  '%lf %lf'\n",
+            dp->status->xpnotchpband[0], dp->status->xpnotchpband[1]);
+    if (dp->param->nnotches > 0) {
+        fprintf(fp, "# NumberOfNotches         '%d'\n", dp->param->nnotches);
+        fprintf(fp, "# NotchesInAvXPSpectrum   '");
+        for (ii = 0; ii < dp->param->nnotches; ii++)
+            fprintf(fp, " %lf", dp->status->xpnotchpband[ii]);
+        fprintf(fp, "'\n");
+    }
+
+    //FIXME -- yet morethings that should be output
 }
 
 /*
@@ -301,16 +358,16 @@ static void dump_onedim(FILE *fp, char *lb, int pr, int npts, double *data)
 /*
  * Calls dump_onedim twice for magnitude and phase
  */
-static void dump_xpspec(FILE *fp, char *lb, int pr, int npts, complex *data)
+static void dump_xpspec(FILE *fp, char *lb, int pr, int npts, hops_complex *data)
 {
     static char lab[20];
     static double vec[2*MAXLAG];
     int ii;
     snprintf(lab, sizeof(lab), "%s-ABS", lb);
-    for (ii = 0; ii < npts; ii++) vec[ii] = cabs(data[ii]);
+    for (ii = 0; ii < npts; ii++) vec[ii] = abs_complex(data[ii]);
     dump_onedim(fp, lab, pr, npts, vec);
     snprintf(lab, sizeof(lab), "%s-ARG", lb);
-    for (ii = 0; ii < npts; ii++) vec[ii] = R2D(carg(data[ii]));
+    for (ii = 0; ii < npts; ii++) vec[ii] = R2D(arg_complex(data[ii]));
     dump_onedim(fp, lab, pr, npts, vec);
 }
 
@@ -351,7 +408,7 @@ static void dump_twodim(FILE *fp, char *lb, int pr, int npts, int apo, int nap,
  * Cf fill_212.c for use of status->amp_corr_fact
  */
 static void dump_phasor(FILE *fp, char *lb, int pr, int npts, int apo, int nap,
-    double period, double start, complex w[][MAXAP], double acf)
+    double period, double start, hops_complex w[][MAXAP], double acf)
 {
     static char lab[20];
     static double vec[MAXFREQ+1][MAXAP];
@@ -359,12 +416,12 @@ static void dump_phasor(FILE *fp, char *lb, int pr, int npts, int apo, int nap,
     snprintf(lab, sizeof(lab), "%s-ABS", lb);
     for (ap = apo; ap < nap; ap++)
         for (ii = 0; ii < npts; ii++)
-            vec[ii][ap] = cabs(w[ii][ap]) * acf;
+            vec[ii][ap] = abs_complex(w[ii][ap]) * acf;
     dump_twodim(fp, lab, pr, npts, apo, nap, period, start, vec);
     snprintf(lab, sizeof(lab), "%s-ARG", lb);
     for (ap = apo; ap < nap; ap++)
         for (ii = 0; ii < npts; ii++)
-            vec[ii][ap] = R2D(carg(w[ii][ap]));
+            vec[ii][ap] = R2D(arg_complex(w[ii][ap]));
     dump_twodim(fp, lab, pr, npts, apo, nap, period, start, vec);
 }
 
@@ -444,7 +501,7 @@ static void dump_ampfilter(FILE *fp, char *lb, int pr, int npts, int nseg,
             if (ahfv > 0.0)
                 fprintf(fp, ffmt, (y[nn][sap] > ahfv) ? 0xFF : 0x00,
                     (nn == nptsm1) ? "\n" : "");
-            else 
+            else
                 fprintf(fp, fmt, y[nn][sap], (nn == nptsm1) ? '\n' : ' ');
         }
     }
@@ -675,6 +732,7 @@ void dump_plot_data2dir(struct type_dump *dump)
     if (rv < 0 && errno == ENOENT) {
         rv = mkdir(outdir, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
         if (rv < 0) perror("dump_plot_data2dir:mkdir");
+        errno = 0;
     } else if (rv < 0) {
         perror("dump_plot_data2dir:stat");
     }
