@@ -7,23 +7,25 @@
 *  inverted sign for ap_by_ap pcal for remote stn rjc 2008.10.31 *
 *  save pcal phasor, rather than applying it      rjc 2011.12.21 *
 *  fixed multitone phase sign bug                 rjc 2013.5.9   *
+*  fixed index offset bug for ad hoc code         rjc 2018.4.12  *
 *****************************************************************/
 #include <stdio.h>
 #include <math.h>
-#include <complex.h>
+
+#include "hops_complex.h"
 #include "mk4_data.h"
 #include "param_struct.h"
 #include "pass_struct.h"
 
 
-rotate_pcal(struct type_pass *pass)
+void rotate_pcal(struct type_pass *pass)
     {
     int ap, fr, i, ip;
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L, 1:R
-    complex rrpcal[2];
-    double theta, 
+    hops_complex rrpcal[2];
+    double theta,
            phaze,thyme,thyme_n,zeta,
-           deltaf, 
+           deltaf,
            eta[4];
     struct data_corel *cor_data;
     struct interp_sdata *rrisd[2];
@@ -51,14 +53,14 @@ rotate_pcal(struct type_pass *pass)
             {
             if (param.ah_phase == SINEWAVE)    /* evaluate ad hoc phase model */
                 {                       /* compute phase at center of AP */
-                phaze = ((ap-0.5) * param.acc_period + param.start - param.ah_tref) 
+                phaze = ((ap + 0.5) * param.acc_period + param.start - param.ah_tref)
                         / param.ah_period * 2.0 * M_PI;
                 zeta = param.ah_amp * sin (phaze);
                 }
             else if (param.ah_phase == POLYNOMIAL)
                 {
                 zeta = 0.0;
-                thyme = (ap-1) * param.acc_period + param.start - param.ah_tref;
+                thyme = (ap + 0.5) * param.acc_period + param.start - param.ah_tref;
                 thyme_n = 1.0;
                 for (i=0; i<6; i++)
                     {
@@ -69,18 +71,18 @@ rotate_pcal(struct type_pass *pass)
                                         // in adhoc file mode, find difference phase (f,t)
             else if (param.ah_phase == PHYLE)
                 {
-                thyme = ((ap-0.5) * param.acc_period + param.start) / 8.64e4;
+                thyme = ((ap + 0.5) * param.acc_period + param.start) / 8.64e4;
                 zeta = diff_file_phase (pass, pass->pass_data[fr].freq_code, thyme);
                 }
             else
                 zeta = 0.0;             /* no ad hoc phase model */
-                                                                            
+
             cor_data = &(pass->pass_data[fr].data[ap]);
             rrisd[0] = &(cor_data->ref_sdata);
             rrisd[1] = &(cor_data->rem_sdata);
 
                                         /* Any bit set implies data present */
-            if (cor_data->flag == 0) 
+            if (cor_data->flag == 0)
                 continue;               // skip out to next ap
 
             for (ip=0; ip<4; ip++)      // loop over four possible pol products
@@ -93,27 +95,27 @@ rotate_pcal(struct type_pass *pass)
                         case NORMAL:
                         case MANUAL:
                                         // apply constant pcal to whole scan
-                            rrpcal[i] = cexp (I * status.pc_phase[fr][i][stnpol[i][ip]]);
+                            rrpcal[i] = exp_complex (cmplx_unit_I * status.pc_phase[fr][i][stnpol[i][ip]]);
                             break;
                         case AP_BY_AP:
                                         // form difference with correct pol
                             rrpcal[i] = (stnpol[i][ip]) ?
                                 rrisd[i]->phasecal_rcp[pass->pci[i][fr]]:
                                 rrisd[i]->phasecal_lcp[pass->pci[i][fr]];
-                            rrpcal[i] = conj (rrpcal[i]);
+                            rrpcal[i] = conjugate (rrpcal[i]);
                             break;
                         case MULTITONE:
                             rrpcal[i] = rrisd[i]->mt_pcal[stnpol[i][ip]];
                             break;
                         }
-                    theta += (2*i-1) * carg (rrpcal[i]);
+                    theta += (2*i-1) * arg_complex (rrpcal[i]);
                     }
-                                        // Zero pcal ampl => missing pcal data   
+                                        // Zero pcal ampl => missing pcal data
                                         // so don't rotate
-                if (cabs (rrpcal[0]) + cabs (rrpcal[1]) == 0.0) 
+                if (abs_complex (rrpcal[0]) + abs_complex (rrpcal[1]) == 0.0)
                     theta = 0.0;
                                         // save resulting phasor in time-freq array
-                cor_data->pc_phasor[ip] = cexp (I * (theta - zeta + eta[ip]));
+                cor_data->pc_phasor[ip] = exp_complex (cmplx_unit_I * (theta - zeta + eta[ip]));
                 }
             }
         }
